diff --git a/include/llvm/MC/MCAsmInfoCOFF.h b/include/llvm/MC/MCAsmInfoCOFF.h
index b5e3d709239..a3ee1593c3a 100644
--- a/include/llvm/MC/MCAsmInfoCOFF.h
+++ b/include/llvm/MC/MCAsmInfoCOFF.h
@@ -13,9 +13,9 @@
 #include "llvm/MC/MCAsmInfo.h"
 
 namespace llvm {
-  class COFFMCAsmInfo : public MCAsmInfo {
+  class MCAsmInfoCOFF : public MCAsmInfo {
   protected:
-    explicit COFFMCAsmInfo();
+    explicit MCAsmInfoCOFF();
       
   };
 }
diff --git a/include/llvm/MC/MCAsmInfoDarwin.h b/include/llvm/MC/MCAsmInfoDarwin.h
index b44babc87f5..c85aa3da957 100644
--- a/include/llvm/MC/MCAsmInfoDarwin.h
+++ b/include/llvm/MC/MCAsmInfoDarwin.h
@@ -23,8 +23,8 @@ namespace llvm {
   class Type;
   class Mangler;
 
-  struct DarwinMCAsmInfo : public MCAsmInfo {
-    explicit DarwinMCAsmInfo();
+  struct MCAsmInfoDarwin : public MCAsmInfo {
+    explicit MCAsmInfoDarwin();
   };
 }
 
diff --git a/lib/MC/MCAsmInfoDarwin.cpp b/lib/MC/MCAsmInfoDarwin.cpp
index 8e8c6f838e3..38b9e5b90b5 100644
--- a/lib/MC/MCAsmInfoDarwin.cpp
+++ b/lib/MC/MCAsmInfoDarwin.cpp
@@ -15,7 +15,7 @@
 #include "llvm/MC/MCAsmInfoDarwin.h"
 using namespace llvm;
 
-DarwinMCAsmInfo::DarwinMCAsmInfo() {
+MCAsmInfoDarwin::MCAsmInfoDarwin() {
   // Common settings for all Darwin targets.
   // Syntax:
   GlobalPrefix = "_";
diff --git a/lib/Target/ARM/ARMMCAsmInfo.cpp b/lib/Target/ARM/ARMMCAsmInfo.cpp
index ed6f6b2b398..0ff65d2af88 100644
--- a/lib/Target/ARM/ARMMCAsmInfo.cpp
+++ b/lib/Target/ARM/ARMMCAsmInfo.cpp
@@ -40,7 +40,7 @@ static const char *const arm_asm_table[] = {
   0,0
 };
 
-ARMDarwinMCAsmInfo::ARMDarwinMCAsmInfo() {
+ARMMCAsmInfoDarwin::ARMMCAsmInfoDarwin() {
   AsmTransCBE = arm_asm_table;
   Data64bitsDirective = 0;
   CommentString = "@";
diff --git a/lib/Target/ARM/ARMMCAsmInfo.h b/lib/Target/ARM/ARMMCAsmInfo.h
index e263ece1ac1..90f7822ea58 100644
--- a/lib/Target/ARM/ARMMCAsmInfo.h
+++ b/lib/Target/ARM/ARMMCAsmInfo.h
@@ -18,8 +18,8 @@
 
 namespace llvm {
 
-  struct ARMDarwinMCAsmInfo : public DarwinMCAsmInfo {
-    explicit ARMDarwinMCAsmInfo();
+  struct ARMMCAsmInfoDarwin : public MCAsmInfoDarwin {
+    explicit ARMMCAsmInfoDarwin();
   };
 
   struct ARMELFMCAsmInfo : public MCAsmInfo {
diff --git a/lib/Target/ARM/ARMTargetMachine.cpp b/lib/Target/ARM/ARMTargetMachine.cpp
index ae5107aff2b..6a8519a9e9b 100644
--- a/lib/Target/ARM/ARMTargetMachine.cpp
+++ b/lib/Target/ARM/ARMTargetMachine.cpp
@@ -32,7 +32,7 @@ static const MCAsmInfo *createMCAsmInfo(const Target &T,
   Triple TheTriple(TT);
   switch (TheTriple.getOS()) {
   case Triple::Darwin:
-    return new ARMDarwinMCAsmInfo();
+    return new ARMMCAsmInfoDarwin();
   default:
     return new ARMELFMCAsmInfo();
   }
diff --git a/lib/Target/PowerPC/PPCMCAsmInfo.cpp b/lib/Target/PowerPC/PPCMCAsmInfo.cpp
index c9ff842e9f1..c87879b2a33 100644
--- a/lib/Target/PowerPC/PPCMCAsmInfo.cpp
+++ b/lib/Target/PowerPC/PPCMCAsmInfo.cpp
@@ -7,14 +7,14 @@
 //
 //===----------------------------------------------------------------------===//
 //
-// This file contains the declarations of the DarwinMCAsmInfo properties.
+// This file contains the declarations of the MCAsmInfoDarwin properties.
 //
 //===----------------------------------------------------------------------===//
 
 #include "PPCMCAsmInfo.h"
 using namespace llvm;
 
-PPCDarwinMCAsmInfo::PPCDarwinMCAsmInfo(bool is64Bit) {
+PPCMCAsmInfoDarwin::PPCMCAsmInfoDarwin(bool is64Bit) {
   PCSymbol = ".";
   CommentString = ";";
   ExceptionsType = ExceptionHandling::Dwarf;
diff --git a/lib/Target/PowerPC/PPCTargetMachine.cpp b/lib/Target/PowerPC/PPCTargetMachine.cpp
index de3a3d0b70d..3371954c30f 100644
--- a/lib/Target/PowerPC/PPCTargetMachine.cpp
+++ b/lib/Target/PowerPC/PPCTargetMachine.cpp
@@ -25,7 +25,7 @@ static const MCAsmInfo *createMCAsmInfo(const Target &T,
   Triple TheTriple(TT);
   bool isPPC64 = TheTriple.getArch() == Triple::ppc64;
   if (TheTriple.getOS() == Triple::Darwin)
-    return new PPCDarwinMCAsmInfo(isPPC64);
+    return new PPCMCAsmInfoDarwin(isPPC64);
   return new PPCLinuxMCAsmInfo(isPPC64);
   
 }
diff --git a/lib/Target/X86/X86MCAsmInfo.cpp b/lib/Target/X86/X86MCAsmInfo.cpp
index 9393fb8bcc2..eaa73e19879 100644
--- a/lib/Target/X86/X86MCAsmInfo.cpp
+++ b/lib/Target/X86/X86MCAsmInfo.cpp
@@ -43,7 +43,7 @@ static const char *const x86_asm_table[] = {
   "{cc}", "cc",
   0,0};
 
-X86DarwinMCAsmInfo::X86DarwinMCAsmInfo(const Triple &Triple) {
+X86MCAsmInfoDarwin::X86MCAsmInfoDarwin(const Triple &Triple) {
   AsmTransCBE = x86_asm_table;
   AssemblerDialect = AsmWriterFlavor;
     
@@ -101,7 +101,7 @@ X86ELFMCAsmInfo::X86ELFMCAsmInfo(const Triple &Triple) {
     NonexecutableStackDirective = "\t.section\t.note.GNU-stack,\"\",@progbits";
 }
 
-X86COFFMCAsmInfo::X86COFFMCAsmInfo(const Triple &Triple) {
+X86MCAsmInfoCOFF::X86MCAsmInfoCOFF(const Triple &Triple) {
   AsmTransCBE = x86_asm_table;
   AssemblerDialect = AsmWriterFlavor;
 }
diff --git a/lib/Target/X86/X86MCAsmInfo.h b/lib/Target/X86/X86MCAsmInfo.h
index 7c1bfac6641..18e2bdbcba9 100644
--- a/lib/Target/X86/X86MCAsmInfo.h
+++ b/lib/Target/X86/X86MCAsmInfo.h
@@ -21,16 +21,16 @@
 namespace llvm {
   class Triple;
 
-  struct X86DarwinMCAsmInfo : public DarwinMCAsmInfo {
-    explicit X86DarwinMCAsmInfo(const Triple &Triple);
+  struct X86MCAsmInfoDarwin : public MCAsmInfoDarwin {
+    explicit X86MCAsmInfoDarwin(const Triple &Triple);
   };
 
   struct X86ELFMCAsmInfo : public MCAsmInfo {
     explicit X86ELFMCAsmInfo(const Triple &Triple);
   };
 
-  struct X86COFFMCAsmInfo : public COFFMCAsmInfo {
-    explicit X86COFFMCAsmInfo(const Triple &Triple);
+  struct X86MCAsmInfoCOFF : public MCAsmInfoCOFF {
+    explicit X86MCAsmInfoCOFF(const Triple &Triple);
   };
 
   struct X86WinMCAsmInfo : public MCAsmInfo {
diff --git a/lib/Target/X86/X86TargetMachine.cpp b/lib/Target/X86/X86TargetMachine.cpp
index 689cebd57b0..4651f462a5d 100644
--- a/lib/Target/X86/X86TargetMachine.cpp
+++ b/lib/Target/X86/X86TargetMachine.cpp
@@ -27,11 +27,11 @@ static const MCAsmInfo *createMCAsmInfo(const Target &T,
   Triple TheTriple(TT);
   switch (TheTriple.getOS()) {
   case Triple::Darwin:
-    return new X86DarwinMCAsmInfo(TheTriple);
+    return new X86MCAsmInfoDarwin(TheTriple);
   case Triple::MinGW32:
   case Triple::MinGW64:
   case Triple::Cygwin:
-    return new X86COFFMCAsmInfo(TheTriple);
+    return new X86MCAsmInfoCOFF(TheTriple);
   case Triple::Win32:
     return new X86WinMCAsmInfo(TheTriple);
   default:
diff --git a/lib/MC/MCAsmInfoCOFF.cpp b/lib/MC/MCAsmInfoCOFF.cpp
index 7586eaceb63..23b0dd77916 100644
--- a/lib/MC/MCAsmInfoCOFF.cpp
+++ b/lib/MC/MCAsmInfoCOFF.cpp
@@ -1,4 +1,4 @@
 //===-- COFFMCAsmInfo.cpp - COFF asm properties -----------------*- C++ -*-===//
 //
 //                     The LLVM Compiler Infrastructure
 //
@@ -16,7 +16,7 @@
 #include "llvm/ADT/SmallVector.h"
 using namespace llvm;
 
-COFFMCAsmInfo::COFFMCAsmInfo() {
+MCAsmInfoCOFF::MCAsmInfoCOFF() {
   GlobalPrefix = "_";
   LCOMMDirective = "\t.lcomm\t";
   COMMDirectiveTakesAlignment = false;
@@ -1,4 +1,4 @@
-//===-- COFFMCAsmInfo.cpp - COFF asm properties -----------------*- C++ -*-===//
+//===-- MCAsmInfoCOFF.cpp - COFF asm properties -----------------*- C++ -*-===//
 //
 //                     The LLVM Compiler Infrastructure
diff --git a/lib/Target/PowerPC/PPCMCAsmInfo.h b/lib/Target/PowerPC/PPCMCAsmInfo.h
index 3f5118b8db1..96ae6fbba0e 100644
--- a/lib/Target/PowerPC/PPCMCAsmInfo.h
+++ b/lib/Target/PowerPC/PPCMCAsmInfo.h
@@ -7,7 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 //
 // This file contains the declaration of the DarwinMCAsmInfo class.
 //
 //===----------------------------------------------------------------------===//
 
@@ -18,8 +18,8 @@
 
 namespace llvm {
 
-  struct PPCDarwinMCAsmInfo : public DarwinMCAsmInfo {
-    explicit PPCDarwinMCAsmInfo(bool is64Bit);
+  struct PPCMCAsmInfoDarwin : public MCAsmInfoDarwin {
+    explicit PPCMCAsmInfoDarwin(bool is64Bit);
   };
 
   struct PPCLinuxMCAsmInfo : public MCAsmInfo {
@@ -7,7 +7,7 @@
 //===----------------------------------------------------------------------===//
 //
-// This file contains the declaration of the DarwinMCAsmInfo class.
+// This file contains the declaration of the MCAsmInfoDarwin class.
 //
 //===----------------------------------------------------------------------===//